"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var composeContinuation_1 = require("./utils/composeContinuation");
var composeEvery_1 = require("./utils/composeEvery");
var composePromise_1 = require("./utils/composePromise");
var composeVoid_1 = require("./utils/composeVoid");
var getBoundImplementations_1 = require("./utils/getBoundImplementations");
var FetchGroup = /** @class */ (function () {
    /* tslint:enable:variable-name */
    function FetchGroup(opts) {
        if (opts === void 0) { opts = {}; }
        var _a = opts.plugins, plugins = _a === void 0 ? [] : _a, _b = opts.filters, filters = _b === void 0 ? [] : _b;
        // Store the original filters & plugins
        this.plugins = plugins;
        this.filters = filters;
        // Filters
        this._testRequest =
            composeEvery_1.default(getBoundImplementations_1.default("testRequest", filters));
        this._testResponse =
            composeEvery_1.default(getBoundImplementations_1.default("testResponse", filters));
        // Plugin methods
        this._shouldFetch =
            composeEvery_1.default(getBoundImplementations_1.default("shouldFetch", plugins));
        this._getRequest =
            composePromise_1.default(getBoundImplementations_1.default("getRequest", plugins));
        this._willFetch =
            composeVoid_1.default(getBoundImplementations_1.default("willFetch", plugins));
        this._fetch =
            composeContinuation_1.default(getBoundImplementations_1.default("fetch", plugins));
        this._fetching =
            composeVoid_1.default(getBoundImplementations_1.default("fetching", plugins));
        this._getResponse =
            composePromise_1.default(getBoundImplementations_1.default("getResponse", plugins));
        this._didFetch =
            composeVoid_1.default(getBoundImplementations_1.default("didFetch", plugins));
    }
    // Plugins
    FetchGroup.prototype.shouldFetch = function (req) {
        return this._testRequest(req) && this._shouldFetch(req);
    };
    FetchGroup.prototype.getRequest = function (req) {
        if (this._testRequest(req)) {
            return this._getRequest(req);
        }
        return Promise.resolve(req);
    };
    FetchGroup.prototype.willFetch = function (req) {
        if (this._testRequest(req)) {
            return this._willFetch(req);
        }
    };
    FetchGroup.prototype.fetch = function (request, fetch) {
        return this._fetch(request, fetch);
    };
    FetchGroup.prototype.fetching = function (args) {
        var request = args.request;
        if (this._testRequest(request)) {
            return this._fetching(args);
        }
    };
    FetchGroup.prototype.getResponse = function (res, maybeRetry) {
        // If no retry is supplied by the engine then we should just continue
        // with the same response.
        var retry = (typeof maybeRetry === "function" ?
            maybeRetry :
            function () { return Promise.resolve(res); });
        if (this._testResponse(res)) {
            return this._getResponse(res, retry);
        }
        return Promise.resolve(res);
    };
    FetchGroup.prototype.didFetch = function (res) {
        if (this._testResponse(res)) {
            return this._didFetch(res);
        }
    };
    return FetchGroup;
}());
exports.default = FetchGroup;
//# sourceMappingURL=FetchGroup.js.map