"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable:no-var-requires max-classes-per-file
require("whatwg-fetch");
var FetchGroup_1 = require("../FetchGroup");
it("FetchGroup is requireable", function () {
    expect.assertions(1);
    expect(FetchGroup_1.default).toBeTruthy();
});
it("FetchGroup has default plugin implementations", function () {
    expect.assertions(8);
    var group = new FetchGroup_1.default();
    var mockRequest = new Request("/mock");
    var mockResponse = new Response();
    var mockPromise = Promise.resolve(mockResponse);
    expect(group.shouldFetch(mockRequest)).toBeTruthy();
    expect(typeof group.willFetch === "function").toBeTruthy();
    expect(typeof group.fetch === "function").toBeTruthy();
    expect(typeof group.fetching === "function").toBeTruthy();
    expect(typeof group.didFetch === "function").toBeTruthy();
    return Promise.resolve()
        .then(function () { return group.getRequest(mockRequest); })
        .then(function (req) {
        expect(req).toEqual(mockRequest);
    })
        .then(function () { return group.fetch(mockRequest, function () { return mockPromise; }); })
        .then(function (res) {
        expect(res).toEqual(mockResponse);
        return group.getResponse(res);
    })
        .then(function (res) {
        expect(res).toEqual(mockResponse);
    });
});
// shouldFetch
test("shouldFetch true value is respected", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        plugins: [
            {
                shouldFetch: function () { return true; },
            },
        ],
    });
    expect(group.shouldFetch(mockReq)).toEqual(true);
});
test("shouldFetch false value is respected", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        plugins: [
            {
                shouldFetch: function () { return false; },
            },
        ],
    });
    expect(group.shouldFetch(mockReq)).toEqual(false);
});
test("shouldFetch true value is respected with multiple plugins", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        plugins: [
            {
                shouldFetch: function () { return true; },
            },
            {
                shouldFetch: function () { return true; },
            },
        ],
    });
    expect(group.shouldFetch(mockReq)).toEqual(true);
});
test("shouldFetch false value is respected with multiple plugins", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        plugins: [
            {
                shouldFetch: function () { return true; },
            },
            {
                shouldFetch: function () { return false; },
            },
        ],
    });
    expect(group.shouldFetch(mockReq)).toEqual(false);
});
// getRequest
it("getRequest is passed the input request", function () {
    expect.assertions(2);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        plugins: [
            {
                getRequest: function (req) {
                    expect(req).toEqual(mockReq);
                    return Promise.resolve(req);
                },
            },
        ],
    });
    return group.getRequest(mockReq)
        .then(function (req) {
        expect(req).toEqual(mockReq);
    });
});
it("getRequest output is passed back", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var newReq = new Request("/another-mock");
    var group = new FetchGroup_1.default({
        plugins: [
            {
                getRequest: function (req) {
                    return Promise.resolve(newReq);
                },
            },
        ],
    });
    return group.getRequest(mockReq)
        .then(function (req) {
        expect(req).toEqual(newReq);
    });
});
it("getRequest output is passed back with multiple plugins", function () {
    expect.assertions(3);
    var mockReq = new Request("/mock");
    var secondReq = new Request("/another-mock");
    var thirdReq = new Request("/another-mock");
    var group = new FetchGroup_1.default({
        plugins: [
            {
                getRequest: function (req) {
                    expect(req).toEqual(mockReq);
                    return Promise.resolve(secondReq);
                },
            },
            {
                getRequest: function (req) {
                    expect(req).toEqual(secondReq);
                    return Promise.resolve(thirdReq);
                },
            },
        ],
    });
    return group.getRequest(mockReq)
        .then(function (req) {
        expect(req).toEqual(thirdReq);
    });
});
// willFetch
it("willFetch is passed the input request", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        plugins: [
            {
                willFetch: function (req) {
                    expect(req).toEqual(mockReq);
                },
            },
        ],
    });
    group.willFetch(mockReq);
});
it("willFetch output is ignored", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        plugins: [
            {
                willFetch: function (req) {
                    return true;
                },
            },
        ],
    });
    var result = group.willFetch(mockReq);
    expect(result).toEqual(undefined);
});
it("willFetch is passed the same request in multiple plugins", function () {
    expect.assertions(2);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        plugins: [
            {
                willFetch: function (req) {
                    expect(req).toEqual(mockReq);
                },
            },
            {
                willFetch: function (req) {
                    expect(req).toEqual(mockReq);
                },
            },
        ],
    });
    group.willFetch(mockReq);
});
// fetch
it("fetch is passed the input request and a 'next' function which is eventually called", function () {
    expect.assertions(3);
    var mockReq = new Request("/mock");
    var mockResponse = new Response();
    var mockPromise = Promise.resolve(mockResponse);
    var group = new FetchGroup_1.default({
        plugins: [
            {
                fetch: function (request, next) {
                    expect(request).toEqual(mockReq);
                    expect(typeof next === "function").toBeTruthy();
                    return next();
                },
            },
        ],
    });
    return group.fetch(mockReq, function () { return mockPromise; })
        .then(function (res) {
        expect(res).toEqual(mockResponse);
    });
});
it("each fetch step is passed same request & can pass control to the next mock", function () {
    expect.assertions(3);
    var mockReq = new Request("/mock");
    var mockResponse = new Response();
    var mockPromise = Promise.resolve(mockResponse);
    var group = new FetchGroup_1.default({
        plugins: [
            {
                fetch: function (request, next) {
                    expect(request).toEqual(mockReq);
                    return next();
                },
            },
            {
                fetch: function (request, next) {
                    expect(request).toEqual(mockReq);
                    return next();
                },
            },
        ],
    });
    return group.fetch(mockReq, function () { return mockPromise; })
        .then(function (res) {
        expect(res).toEqual(mockResponse);
    });
});
it("a fetch step can return early", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var mockResponse = new Response();
    var mockPromise = Promise.resolve(mockResponse);
    var group = new FetchGroup_1.default({
        plugins: [
            {
                fetch: function (request, next) {
                    return Promise.resolve(mockResponse);
                },
            },
        ],
    });
    return group.fetch(mockReq, function () { return mockPromise; })
        .then(function (res) {
        expect(res).toEqual(mockResponse);
    });
});
// fetching
it("fetching is passed the input request and a promise for the response", function () {
    expect.assertions(2);
    var mockReq = new Request("/mock");
    var mockPromise = Promise.resolve(new Response());
    var group = new FetchGroup_1.default({
        plugins: [
            {
                fetching: function (args) {
                    expect(args.request).toEqual(mockReq);
                    expect(args.promise).toEqual(mockPromise);
                },
            },
        ],
    });
    group.fetching({
        promise: mockPromise,
        request: mockReq,
    });
});
it("fetching is passed same input for multiple plugins", function () {
    expect.assertions(4);
    var mockReq = new Request("/mock");
    var mockPromise = Promise.resolve(new Response());
    var group = new FetchGroup_1.default({
        plugins: [
            {
                fetching: function (args) {
                    expect(args.request).toEqual(mockReq);
                    expect(args.promise).toEqual(mockPromise);
                },
            },
            {
                fetching: function (args) {
                    expect(args.request).toEqual(mockReq);
                    expect(args.promise).toEqual(mockPromise);
                },
            },
        ],
    });
    group.fetching({
        promise: mockPromise,
        request: mockReq,
    });
});
// getResponse
it("getResponse is passed the input response", function () {
    expect.assertions(2);
    var mockRes = new Response();
    var group = new FetchGroup_1.default({
        plugins: [
            {
                getResponse: function (res) {
                    expect(res).toEqual(mockRes);
                    return Promise.resolve(res);
                },
            },
        ],
    });
    return group.getResponse(mockRes)
        .then(function (res) {
        expect(res).toEqual(mockRes);
    });
});
it("getResponse output is passed back", function () {
    expect.assertions(1);
    var mockRes = new Response();
    var newRes = new Response();
    var group = new FetchGroup_1.default({
        plugins: [
            {
                getResponse: function (res) {
                    return Promise.resolve(newRes);
                },
            },
        ],
    });
    return group.getResponse(mockRes)
        .then(function (res) {
        expect(res).toEqual(newRes);
    });
});
it("getResponse output is passed back with multiple plugins", function () {
    expect.assertions(3);
    var mockRes = new Response();
    var secondRes = new Response();
    var thirdRes = new Response();
    var group = new FetchGroup_1.default({
        plugins: [
            {
                getResponse: function (req) {
                    expect(req).toEqual(mockRes);
                    return Promise.resolve(secondRes);
                },
            },
            {
                getResponse: function (req) {
                    expect(req).toEqual(secondRes);
                    return Promise.resolve(thirdRes);
                },
            },
        ],
    });
    return group.getResponse(mockRes)
        .then(function (req) {
        expect(req).toEqual(thirdRes);
    });
});
// didFetch
it("didFetch is passed the input response", function () {
    expect.assertions(1);
    var mockRes = new Response();
    var group = new FetchGroup_1.default({
        plugins: [
            {
                didFetch: function (req) {
                    expect(req).toEqual(mockRes);
                },
            },
        ],
    });
    group.didFetch(mockRes);
});
it("didFetch output is ignored", function () {
    expect.assertions(1);
    var mockRes = new Response();
    var group = new FetchGroup_1.default({
        plugins: [
            {
                didFetch: function (req) {
                    return true;
                },
            },
        ],
    });
    var result = group.didFetch(mockRes);
    expect(result).toEqual(undefined);
});
it("didFetch is passed the same response in multiple plugins", function () {
    expect.assertions(2);
    var mockRes = new Response();
    var group = new FetchGroup_1.default({
        plugins: [
            {
                didFetch: function (req) {
                    expect(req).toEqual(mockRes);
                },
            },
            {
                didFetch: function (req) {
                    expect(req).toEqual(mockRes);
                },
            },
        ],
    });
    group.didFetch(mockRes);
});
// testRequest
it("testRequest prevents shouldFetch being called", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        filters: [
            {
                testRequest: function (req) {
                    expect(req).toEqual(mockReq);
                    return false;
                },
            },
        ],
        plugins: [
            {
                shouldFetch: function (req) {
                    throw new Error("shouldFetch was called");
                },
            },
        ],
    });
    group.shouldFetch(mockReq);
});
it("testRequest prevents getRequest being called", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        filters: [
            {
                testRequest: function (req) {
                    expect(req).toEqual(mockReq);
                    return false;
                },
            },
        ],
        plugins: [
            {
                getRequest: function (req) {
                    throw new Error("getRequest was called");
                },
            },
        ],
    });
    group.getRequest(mockReq);
});
it("testRequest prevents willFetch being called", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var group = new FetchGroup_1.default({
        filters: [
            {
                testRequest: function (req) {
                    expect(req).toEqual(mockReq);
                    return false;
                },
            },
        ],
        plugins: [
            {
                willFetch: function (req) {
                    throw new Error("willFetch was called");
                },
            },
        ],
    });
    group.willFetch(mockReq);
});
it("testRequest prevents fetch being called", function () {
    expect.assertions(1);
    var mockReq = new Request("/mock");
    var mockResp = new Response();
    var mockPromise = Promise.resolve(mockResp);
    var group = new FetchGroup_1.default({
        filters: [
            {
                testRequest: function (req) {
                    expect(req).toEqual(mockReq);
                    return false;
                },
            },
        ],
        plugins: [
            {
                fetching: function (args) {
                    throw new Error("fetch was called");
                },
            },
        ],
    });
    group.fetching({
        promise: mockPromise,
        request: mockReq,
    });
});
// testResponse
it("testResponse prevents getResponse being called", function () {
    expect.assertions(1);
    var mockRes = new Response();
    var group = new FetchGroup_1.default({
        filters: [
            {
                testResponse: function (res) {
                    expect(res).toEqual(mockRes);
                    return false;
                },
            },
        ],
        plugins: [
            {
                getResponse: function (res) {
                    throw new Error("getResponse was called");
                },
            },
        ],
    });
    group.getResponse(mockRes);
});
it("testResponse prevents didFetch being called", function () {
    expect.assertions(1);
    var mockRes = new Response();
    var group = new FetchGroup_1.default({
        filters: [
            {
                testResponse: function (res) {
                    expect(res).toEqual(mockRes);
                    return false;
                },
            },
        ],
        plugins: [
            {
                didFetch: function (res) {
                    throw new Error("didFetch was called");
                },
            },
        ],
    });
    group.didFetch(mockRes);
});
//# sourceMappingURL=FetchGroup.test.js.map