"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// tslint:disable:no-var-requires
require("whatwg-fetch");
var jest_1 = require("../../integration-tests/jest");
var fetch_browser_1 = require("../fetch-browser");
it("fetch-browser is requirable", function () {
    expect.assertions(1);
    expect(fetch_browser_1.default).toBeTruthy();
});
it("fetch-browser can make a request to the test server", function () {
    expect.assertions(2);
    var req = new Request(jest_1.ORIGIN + "/echo/text/" + encodeURIComponent("Hello fetch-browser"));
    return fetch_browser_1.default(req)
        .then(function (res) {
        expect(res).toBeTruthy();
        return res.text();
    })
        .then(function (text) {
        expect(text).toEqual("Hello fetch-browser");
    });
});
it("fetch-browser can set headers", function () {
    expect.assertions(1);
    var req = new Request(jest_1.ORIGIN + "/echo/header/x-example", { headers: { "X-Example": "example" } });
    return fetch_browser_1.default(req)
        .then(function (res) { return res.text(); })
        .then(function (text) {
        expect(text).toEqual("example");
    });
});
it("fetch-browser can POST a string body", function () {
    expect.assertions(1);
    var req = new Request(jest_1.ORIGIN + "/echo/body", {
        body: "example",
        headers: {
            "Content-Type": "text/html",
        },
        method: "POST",
    });
    return fetch_browser_1.default(req)
        .then(function (res) { return res.text(); })
        .then(function (text) {
        expect(text).toEqual("example");
    });
});
it("fetch-browser can POST a JSON body", function () {
    expect.assertions(1);
    var body = JSON.stringify({ a: 10 });
    var req = new Request(jest_1.ORIGIN + "/echo/body", {
        body: body,
        headers: {
            "Content-Type": "application/json",
        },
        method: "POST",
    });
    return fetch_browser_1.default(req)
        .then(function (res) { return res.text(); })
        .then(function (text) {
        expect(text).toEqual(body);
    });
});
it("fetch-browser can parse a JSON response", function () {
    expect.assertions(1);
    var body = { a: 10 };
    var req = new Request(jest_1.ORIGIN + "/echo/body", {
        body: JSON.stringify(body),
        headers: {
            "Content-Type": "application/json",
        },
        method: "POST",
    });
    return fetch_browser_1.default(req)
        .then(function (res) { return res.json(); })
        .then(function (data) {
        expect(data).toEqual(body);
    });
});
it("fetch-browser can send cookies to same-origin", function () {
    expect.assertions(1);
    document.cookie = "example-cookie=;";
    document.cookie = "example-cookie=example";
    var req = new Request(jest_1.SAME_ORIGIN + "/echo/cookie/example-cookie", {
        credentials: "same-origin",
    });
    return fetch_browser_1.default(req)
        .then(function (res) { return res.text(); })
        .then(function (text) {
        expect(text).toEqual("example");
    });
});
it("fetch-browser handles an error", function () {
    expect.assertions(2);
    var req = new Request(jest_1.ORIGIN + "/error/500");
    return fetch_browser_1.default(req)
        .then(function (res) {
        expect(res.status).toEqual(500);
        expect(res.ok).toEqual(false);
    });
});
// Tests matching github/fetch
it("fetch request", function () {
    expect.assertions(2);
    var req = new Request(jest_1.ORIGIN + "/echo", {
        headers: {
            "Accept": "application/json",
            "X-Test": "42",
        },
    });
    return fetch_browser_1.default(req)
        .then(function (res) { return res.json(); })
        .then(function (json) {
        expect(json.headers.accept).toEqual("application/json");
        expect(json.headers["x-test"]).toEqual("42");
    });
});
it("populates response", function () {
    expect.assertions(4);
    var req = new Request(jest_1.ORIGIN + "/echo/text/hello");
    return fetch_browser_1.default(req)
        .then(function (res) {
        expect(res.status).toEqual(200);
        expect(res.ok).toEqual(true);
        expect(res.headers.get("Content-Type")).toEqual("text/html; charset=utf-8");
        return res.text();
    })
        .then(function (text) {
        expect(text).toEqual("hello");
    });
});
it("supports POST", function () {
    expect.assertions(2);
    var req = new Request(jest_1.ORIGIN + "/echo", {
        body: "a=10",
        headers: {
            "Content-Type": "application/x-www-form-urlencoded",
        },
        method: "post",
    });
    return fetch_browser_1.default(req)
        .then(function (res) { return res.json(); })
        .then(function (json) {
        expect(json.method).toEqual("post");
        expect(json.payload).toEqual({ a: "10" });
    });
});
it("supports PUT", function () {
    expect.assertions(2);
    var req = new Request(jest_1.ORIGIN + "/echo", {
        body: "a=10",
        headers: {
            "Content-Type": "application/x-www-form-urlencoded",
        },
        method: "put",
    });
    return fetch_browser_1.default(req)
        .then(function (res) { return res.json(); })
        .then(function (json) {
        expect(json.method).toEqual("put");
        expect(json.payload).toEqual({ a: "10" });
    });
});
it("supports DELETE", function () {
    expect.assertions(2);
    var req = new Request(jest_1.ORIGIN + "/echo", {
        method: "delete",
    });
    return fetch_browser_1.default(req)
        .then(function (res) { return res.json(); })
        .then(function (json) {
        expect(json.method).toEqual("delete");
        expect(json.payload).toEqual(null);
    });
});
it("can send requests cross-origin", function () {
    expect.assertions(2);
    var req = new Request(jest_1.CROSS_ORIGIN + "/cors/echo/text/" + encodeURIComponent("Hello fetch-browser"));
    return fetch_browser_1.default(req)
        .then(function (res) {
        expect(res).toBeTruthy();
        return res.text();
    })
        .then(function (text) {
        expect(text).toEqual("Hello fetch-browser");
    });
});
//# sourceMappingURL=fetch-browser.test.js.map