"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var Boom = require("boom");
var basicRoutes = [
    {
        handler: function (request, reply) {
            return reply({
                headers: request.headers,
                method: request.method,
                payload: request.payload,
            });
        },
        method: ["GET", "PUT", "POST", "DELETE"],
        path: "/echo",
    },
    {
        handler: function (request, reply) {
            return reply(decodeURIComponent(request.params.text));
        },
        method: "GET",
        path: "/echo/text/{text}",
    },
    {
        handler: function (request, reply) {
            return reply(request.headers[request.params.key]);
        },
        method: "GET",
        path: "/echo/header/{key}",
    },
    {
        config: {
            payload: {
                parse: true,
            },
        },
        handler: function (request, reply) {
            return reply(request.payload)
                .header("Content-Type", request.headers["content-type"]);
        },
        method: "POST",
        path: "/echo/body",
    },
    {
        handler: function (request, reply) {
            return reply(request.state[request.params.key]);
        },
        method: "GET",
        path: "/echo/cookie/{key}",
    },
    {
        handler: function (request, reply) {
            return reply(Boom.create(500));
        },
        method: "GET",
        path: "/error/{code}",
    },
];
var corsRoutes = basicRoutes.map(function (route) { return (__assign({}, route, { config: __assign({}, route.config, { cors: true }), path: "/cors" + route.path })); });
exports.routes = basicRoutes.concat(corsRoutes);
exports.states = [
    {
        config: {
            path: "/",
            ttl: 0,
        },
        name: "example-cookie",
    },
];
//# sourceMappingURL=routes.js.map